Installation - flytrap 0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Installation

## Stable release

To install flytrap, run this command in your terminal:

    $ pip install flytrap

This is the preferred method to install flytrap, as it will always install the most recent stable release.

To create the documentation, you can install flytrap with the extra `docs`:

    $ pip install flytrap[docs]

To run the tests with pytest, you can install flytrap with the extra `tests`:

    $ pip install flytrap[tests]

If you don’t have pip installed, this Python installation guide can guide you through the process.

## From sources

The sources for flytrap can be downloaded from the Github repo.

You can either clone the public repository:

    $ git clone git://github.com/dodo325/flytrap

Or download the tarball:

    $ curl  -OL https://github.com/dodo325/flytrap/tarball/master

Once you have a copy of the source, you can install it with:

    $ python setup.py install